LetterboxResult class

Internal helper for letterbox transform parameters.

Constructors

LetterboxResult({required Image image, required double ratio, required double padW, required double padH})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
image → Image
final
padH double
final
padW double
final
ratio double
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited